@@ -9,6 +9,7 @@ from typing import Optional
 
 from . import coreio as _c
 from .updatezipfile import UpdateZipFile
+from . import formats
 from ..models.metadata import WorkMetadata, ContributorRoles
 from ..models.matter import MatterPartition, FrontMatter, BodyMatter, BackMatter, Matter
 
@@ -20,6 +21,12 @@ DEFAULT_TOC_NCX = "toc.ncx"
 DEFAULT_TOC_XHTML = "toc.xhtml"
 DEFAULT_COLOPHON_XHTML = "colophon.xhtml"
 DEFAULT_DEDICATION_XHTML = "dedication.xhtml"
+# TITLEPAGE SETTINGS
+TITLEPAGE_TITLE_HEIGHT = 90
+TITLEPAGE_TITLE_START = 150 - TITLEPAGE_TITLE_HEIGHT
+TITLEPAGE_ROW_MARGIN = 20
+TITLEPAGE_AUTHOR_HEIGHT = 75
+SECTION_SPACER = 120
 
 def restructure_chapter(source: bytes):
     """
@@ -64,7 +71,13 @@ def create_titlepage_xhtml(metadata: WorkMetadata) -> str:
     with open(DATA_PATH / "xhtml" / DEFAULT_TITLEPAGE, "r+", encoding="utf-8") as xhtml_file:
         xml_txt = xhtml_file.read()
         # Title
-        xml_txt = xml_txt.replace("WORK_TITLE", metadata.title)
+        title_xml = ""
+        y = TITLEPAGE_TITLE_START
+        for row in formats.get_text_rows(metadata.title):
+            y += TITLEPAGE_TITLE_HEIGHT
+            title_xml += F'\t<text class="title" x="700" y="{y}">{row}</text>\n'
+            y += TITLEPAGE_ROW_MARGIN
+        xml_txt = xml_txt.replace('\t<text class="title" x="700" y="130">WORK_TITLE</text>\n', title_xml)
         # Author/s
         creator = metadata.creator
         if isinstance(creator, list):
@@ -72,8 +85,23 @@ def create_titlepage_xhtml(metadata: WorkMetadata) -> str:
                 creator = " &amp; ".join([", ".join(creator[:-1]), creator[-1]])
             else:
                 creator = creator[0]
-        xml_txt = xml_txt.replace('<text class="author" x="700" y="290">WORK_AUTHOR</text>',
-                                  F'<text class="author" x="700" y="290">{creator}</text>')
+        y += SECTION_SPACER - TITLEPAGE_ROW_MARGIN
+        author_xml = ""
+        for row in formats.get_text_rows(creator, font_size=formats.AUTHOR_SIZE):
+            y += TITLEPAGE_AUTHOR_HEIGHT
+            author_xml += F'\t<text class="author" x="700" y="{y}">{row}</text>\n'
+            y += TITLEPAGE_ROW_MARGIN
+        xml_txt = xml_txt.replace('\t<text class="author" x="700" y="290">WORK_AUTHOR</text>\n', author_xml)
+        # Chapisha boilerplate
+        y += SECTION_SPACER * 2 + TITLEPAGE_AUTHOR_HEIGHT - TITLEPAGE_ROW_MARGIN
+        xml_txt = xml_txt.replace('<text class="contributor-descriptor" x="700" y="480">Generated by Chapisha</text>',
+                                  F'<text class="contributor-descriptor" x="700" y="{y}">Generated by Chapisha</text>')
+        y += SECTION_SPACER - TITLEPAGE_ROW_MARGIN * 2
+        xml_txt = xml_txt.replace('<image x="650" y="540" width="100" height="100" ns:href="../images/logo.svg" />',
+                                  F'<image x="650" y="{y}" width="140" height="140" ns:href="../images/logo.svg" />')
+        y += 150
+        xml_txt = xml_txt.replace(F'viewBox="0 0 1400 700"',
+                                F'viewBox="0 0 1400 {y}"')
     return xml_txt
 
 def create_content_opf(metadata: WorkMetadata, image_manifest: list[str], spine: list[Matter]) -> str:
@@ -109,7 +137,7 @@ def create_content_opf(metadata: WorkMetadata, image_manifest: list[str], spine:
                                   F'<meta property="dcterms:modified">{datetime.datetime.now(zoneinfo.ZoneInfo("Europe/Paris")).isoformat("T", "seconds").split("+")[0]}Z</meta>')
         # dc:rights
         opf_xml = opf_xml.replace('<dc:rights></dc:rights>',
-                                  F'<dc:rights>{metadata.rights[0]} For full license information see the Colophon file included at the end of this ebook.</dc:rights>')
+                                  F'<dc:rights>{metadata.rights} For full license information see the Colophon (colophon.xhtml) included at the end of this ebook.</dc:rights>')
         # dc:publisher
         if metadata.publisher:
             opf_xml = opf_xml.replace('<meta property="se:url.homepage" refines="#generator">https://github.com/whythawk/chapisha</meta>', 
@@ -155,7 +183,7 @@ def create_content_opf(metadata: WorkMetadata, image_manifest: list[str], spine:
         contributor_xml = ""
         if len(metadata.contributor):
             for i, contributor in enumerate(metadata.contributor):
-                contributor_xml += F'\t\t<dc:contributor id="{contributor.id_}-{i+1}">{contributor.name}</dc:contributor>\n'
+                contributor_xml += F'\t\t<dc:contributor id="{contributor.role}-{i+1}">{contributor.name}</dc:contributor>\n'
         opf_xml = opf_xml.replace('\t\t<dc:contributor id="artist"></dc:contributor>\n', 
                                   contributor_xml)
         ################################################################################################################
@@ -293,15 +321,15 @@ def create_colophon_xhtml(metadata: WorkMetadata) -> str:
                 creator = " &amp; ".join([", ".join(creator[:-1]), creator[-1]])
             else:
                 creator = creator[0]
-        xml_txt = xml_txt.replace("AUTHOR, YEAR.", F"{creator}, {metadata.isodate.year}.")
+        xml_txt = xml_txt.replace("AUTHOR, YEAR. RIGHTS.", F"{creator}, {metadata.isodate.year}. {metadata.rights}")
         # Set author url
         xml_url = ""
         if metadata.work_uri:
             xml_url = F'<p><a href="{metadata.work_uri}">{urlparse(metadata.work_uri).netloc}</a><br/></p>'
         xml_txt = xml_txt.replace('<p><a href="AUTHOR_URL">AUTHOR_URL</a><br/></p>', xml_url)
-        # Set publication rights
+        # Set publication long-rights
         xml_rights = ""
-        for p in metadata.rights:
+        for p in metadata.long_rights:
             xml_rights += F"\t\t\t<p>{p}</p>\n"
         xml_txt = xml_txt.replace("\t\t\t<p>PUBLICATION_RIGHTS</p>\n", xml_rights)
         # Set publisher and publisher url
@@ -317,7 +345,7 @@ def create_colophon_xhtml(metadata: WorkMetadata) -> str:
             # If ctrb.year is None, then use work year
             if not ctrb.year:
                 ctrb.year = metadata.isodate.year
-            xml_ctrb += F"<p>{ctrb.id_.capitalize()} contribution is copyright (c) {ctrb.name}, {ctrb.year}. {ctrb.terms}</p>"
+            xml_ctrb += F"<p>{ctrb.role.capitalize()} contribution is copyright (c) {ctrb.name}, {ctrb.year}. {ctrb.terms}</p>"
         xml_txt = xml_txt.replace("<p>CONTRIBUTORS</p>", xml_ctrb)
     return xml_txt
 
